@@ -24,6 +24,7 @@ from keras.src.activations.activations import softmax
 from keras.src.activations.activations import softplus
 from keras.src.activations.activations import softsign
 from keras.src.activations.activations import sparse_plus
+from keras.src.activations.activations import sparse_sigmoid
 from keras.src.activations.activations import sparsemax
 from keras.src.activations.activations import squareplus
 from keras.src.activations.activations import tanh
@@ -53,6 +54,7 @@ ALL_OBJECTS = {
     tanh_shrink,
     threshold,
     sigmoid,
+    sparse_sigmoid,
     exponential,
     hard_sigmoid,
     hard_silu,
@@ -116,7 +118,7 @@ def get(identifier):
     if identifier is None:
         return linear
     if isinstance(identifier, dict):
-        obj = deserialize(identifier)
+        obj = serialization_lib.deserialize_keras_object(identifier)
     elif isinstance(identifier, str):
         obj = ALL_OBJECTS_DICT.get(identifier, None)
     else:
