@@ -13,7 +13,6 @@ class TFLayer(KerasAutoTrackable):
         self._saved_model_arg_spec = None
         self._tracked = []
 
-    @tf.__internal__.tracking.no_automatic_dependency_tracking
     def _set_save_spec(self, inputs, args=None, kwargs=None):
         """Defines the save spec so that serialization can trace layer calls.
 
@@ -45,6 +44,7 @@ class TFLayer(KerasAutoTrackable):
             kwargs_spec,
         )
 
+    @tf.__internal__.tracking.no_automatic_dependency_tracking
     def _trackable_children(self, save_type="checkpoint", **kwargs):
         if save_type == "savedmodel":
             # SavedModel needs to ignore the execution functions.
@@ -62,17 +62,55 @@ class TFLayer(KerasAutoTrackable):
             self.test_function = test_function
             self.predict_function = predict_function
 
-            for tracked_attr in self._tracked:
-                tracked_item = getattr(self, tracked_attr)
-                if isinstance(tracked_item, tracking.TrackedList):
-                    children[tracked_attr] = list(tracked_item)
-                if isinstance(tracked_item, tracking.TrackedDict):
-                    children[tracked_attr] = dict(tracked_item)
-                if isinstance(tracked_item, tracking.TrackedSet):
-                    children[tracked_attr] = list(tracked_item)
+            # Convert Keras tracked collections to plain Python structures
+            # without creating TensorFlow trackable dependencies
+            self._convert_tracked_collections(children)
 
         return children
 
+    def _convert_tracked_collections(self, children):
+        """Convert TrackedList/Dict/Set to plain Python structures."""
+        for tracked_attr in self._tracked:
+            tracked_item = getattr(self, tracked_attr)
+            if isinstance(tracked_item, tracking.TrackedList):
+                children[tracked_attr] = list(tracked_item)
+            if isinstance(tracked_item, tracking.TrackedDict):
+                children[tracked_attr] = dict(tracked_item)
+            if isinstance(tracked_item, tracking.TrackedSet):
+                children[tracked_attr] = list(tracked_item)
+
+    def _get_save_spec(self, dynamic_batch=True):
+        """Compatibility shim for TensorFlow saving utilities.
+
+        TensorFlow's SavedModel / TFLite export paths (e.g.,
+        tf.lite.TFLiteConverter.from_keras_model) expect a `_get_save_spec`
+        method on models. This method generates TensorSpec objects
+        describing the model's input signature.
+
+        Args:
+            dynamic_batch: whether to set the batch dimension to `None`.
+
+        Returns:
+            A TensorSpec, list or dict mirroring the model inputs, or
+            `None` when specs cannot be inferred.
+        """
+        # Prefer the base implementation if available
+        try:
+            return super()._get_save_spec(dynamic_batch)
+        except AttributeError:
+            # Lazy import to avoid circular dependency
+            from keras.src.export.export_utils import make_tf_tensor_spec
+
+            # Fall back to building specs from `self.inputs`
+            inputs = getattr(self, "inputs", None)
+            if inputs is None:
+                return None
+
+            return tree.map_structure(
+                lambda x: make_tf_tensor_spec(x, dynamic_batch=dynamic_batch),
+                inputs,
+            )
+
     @property
     def _default_save_signature(self):
         """For SavedModel support: returns the default serving signature."""
